@@ -5,6 +5,8 @@ globalVariables(
         "week_of_month","week_day","fit","fft","time","x.y","y_actual","y_hat",
         "dff_trans","sma_order","sma_value","min_node","seasonal_period",
         "error","trend","season","damping","smooth_level","smooth_trend",
-        "smooth_seasonal","name","printer"
+        "smooth_seasonal","name","printer","mae","mape","mase","smape","rmse","rsq",
+        "model_score",".model",".type",".calibration_data",".residuals",".model_desc",
+        ".prediction"
     )
 )
